@@ -152,9 +152,17 @@ class CursorWrapper(object):
         try:
             return self.cursor.execute(sql, params)
         except Database.IntegrityError, e:
+            if not self.cursor.connection.mars_enabled:
+                self.cursor.cancel()
             raise utils.IntegrityError, utils.IntegrityError(*tuple(e)), sys.exc_info()[2]
         except Database.DatabaseError, e:
+            if not self.cursor.connection.mars_enabled:
+                self.cursor.cancel()
             raise utils.DatabaseError, utils.DatabaseError(*tuple(e)), sys.exc_info()[2]
+        except Database.Error:
+            if not self.cursor.connection.mars_enabled:
+                self.cursor.cancel()
+            raise
 
     def executemany(self, sql, params):
         try:
