@@ -1,5 +1,5 @@
 from django.db.models import Manager
-from sqlserver_ado.models.query import RawStoredProcedureQuerySet
+from django_pytds.models.query import RawStoredProcedureQuerySet
 
 class RawStoredProcedureManager(Manager):
     """
